[![PyPI Version](https://badge.fury.io/py/humannum.svg)](https://badge.fury.io/py/humannum)
[![Python Build](https://github.com/nbiotcloud/humannum/actions/workflows/main.yml/badge.svg)](https://github.com/nbiotcloud/humannum/actions/workflows/main.yml)
[![Documentation](https://readthedocs.org/projects/humannum/badge/?version=stable)](https://humannum.readthedocs.io/en/stable/?badge=stable)
[![Coverage Status](https://coveralls.io/repos/github/nbiotcloud/humannum/badge.svg?branch=main)](https://coveralls.io/github/nbiotcloud/humannum?branch=main)
[![python-versions](https://img.shields.io/pypi/pyversions/humannum.svg)](https://pypi.python.org/pypi/humannum)

# Human Friendly Numbers

* [Documentation](https://humannum.readthedocs.io/en/stable/)
* [PyPI](https://pypi.org/project/humannum/)
* [Sources](https://github.com/nbiotcloud/humannum)
* [Issues](https://github.com/nbiotcloud/humannum/issues)

## Installation

Installing it is pretty easy:

```bash
pip install humannum
```
